@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,10 +30,7 @@ FilterBalsa::FilterBalsa()
 }
 
 /** Destructor. */
-FilterBalsa::~FilterBalsa()
-{
-    delete d;
-}
+FilterBalsa::~FilterBalsa() = default;
 
 QString FilterBalsa::isMailerFound()
 {
@@ -150,7 +147,8 @@ void FilterBalsa::importFiles(const QString &dirName)
 
     QDir importDir(dirName);
     const QStringList files = importDir.entryList(QStringList(QStringLiteral("[^\\.]*")), QDir::Files, QDir::Name);
-    int currentFile = 1, numFiles = files.size();
+    int currentFile = 1;
+    int numFiles = files.size();
     QStringList::ConstIterator filesEnd(files.constEnd());
 
     for (QStringList::ConstIterator mailFile = files.constBegin(); mailFile != filesEnd; ++mailFile, ++currentFile) {
