@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterclawsmailtest.h"
-#include <MailImporter/FilterClawsMail>
 #include "filterimportertest.h"
+#include <MailImporter/FilterClawsMail>
 #include <QTest>
 
 FilterClawsMailTest::FilterClawsMailTest(QObject *parent)
@@ -26,7 +26,7 @@ void FilterClawsMailTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterClawsMail filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QString());
@@ -38,7 +38,7 @@ void FilterClawsMailTest::canNotImportDataUnknowPath()
 {
     MailImporter::FilterClawsMail filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
@@ -50,7 +50,7 @@ void FilterClawsMailTest::canNotImportDataWhenHomeDirSelected()
 {
     MailImporter::FilterClawsMail filter;
     MailImporter::FilterInfo info;
-    auto *importerTest = new FilterImporterTest(&info);
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
     filter.importMails(QDir::homePath());
